# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project *loosely* adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
The main difference is that the MAJOR.MINOR.PATCH system doesn't change the MAJOR indicator, as most version changes are NOT backwards compatible and the MINOR indicator will increase regardless of if that version can be played in an earlier update.
However, if the version update is a bug fix/patch/update that does NOT change the resourcepack or datapack format, and does NOT otherwise add anything, then the PATCH indicator will be updated accordingly.
TL;DR: This pretty much follows Mojang's update structure for Minecraft updates.

Anything noted as (Undocumented) is because I didn't write down the change at that time and can't remember what was added/removed/edited. Sorry.

Update numbers are written in YYYY/MM/DD format.

## [1.2.0] - 2024-10-25

### Added
#### Foods
38 new foods have been added in this update:
- Added Honeycomb Candy
  - Honeycomb Candy can be crafted from smelting Honeycomb in a Furnace, Smoker, or on a Campfire
  - Consuming it restores 5 Hunger Points and 2 Saturation
    - This item was added to replace consuming Honeycomb, as it can no longer be eaten
- Added Sweet Berry and Glow Berry Jam
  - Berry Jams can be obtained from crushing their respective berry types in a Mortar & Pestle, adding a Water and Honey Bottle to a Shaker Cup, and then placing the mashed up berries inside. After that, deposit the result in a bowl
  - Consuming it restores 8 Hunger Points and 6 Saturation
- Added Prickly Pears
  - Prickly Pears can be obtained from breaking Cactus with a Cleaver, or can also be crafted by putting a Cactus in a Stonecutter
  - It restores 4 Hunger Points and 3 Saturation, making it a slightly better alternative to apples
    - The idea behind adding Prickly Pears is to give players who may be stuck in/live in a Desert biome a reliable source of food to survive on
- Added Peaches
  - Peaches can be found in Cherry Trees, and restore the same food values as Apples, making them a nice snack if you're hungry and passing by a Cherry Grove
  - Consuming it restores 4 Hunger Points and 2.4 Saturation
- Added Coconut Chunks
  - Coconut Chunks can be obtained by crushing Coconuts in a Mortar & Pestle, and can be eaten for 3 Hunger Points and 2.4 Saturation
  - They can be processed further into Coconut Mash using a Mortar & Pestle
- Added Strawberries
- Added Blueberries
- Added Raspberries
- Added Blackberries
  - Berries can be obtained from breaking Short Grass or Fern blocks while in one of the 4 following biomes: Plains, Taiga, Savanna, and Snowy (deserts are excluded because of the extreme lack of humidity and water, even if Bone Meal can be used to grow grass there)
  - They can also be found in Village Chests of their respective biomes (so Blueberries can be found in Taiga Village Chests, for example)
    - Due to the fact that Snowy biomes have harsher conditions for plant life, Blackberries are somewhat rarer to find in grass than the other berry types. Despite this, all berries share a food value of 3 Hunger Points and 1 Saturation (and can be eaten at any time)
  - Dissapointingly, none of the added berries are usable in any Crafting Table recipes due to data pack limitations
  - Currently, Berries can be crafted from 1 Short Grass/Fern, 7 Wheat Seeds, and a berry's respective dye color. When Mojang adds data driven items/blocks to the game (🙏) a berry crop will be added and this recipe will be removed
- Added Melon Smoothies
- Added Banana Smoothies
- Added Strawberry Smoothies
- Added Blueberry Smoothies
- Added Raspberry Smoothies
- Added Blackberry Smoothies
- Added Peach Smoothies
- Added Mango Smoothies
  - All smoothies are prepared the same way, with the only differences being the last ingredient used defining what smoothie crafted
  - Smoothies all restore 4 Hunger and 4 Saturation when consumed (with the exception of the Mango Smoothie restoring 5 Saturation), but the player must be hungry to drink them
  - Crafting a smoothie yields 3 of the recipe used (so making a Strawberry Smoothie recipe will yield 3 Strawberry Smoothie bottles)
- Added Fried Tofu
  - Tofu can now be cooked into Fried Tofu, which gives 4 Hunger Points, and 2 Saturation. The trade off is that it can't be used in recipes anymore, and can't be eaten whenever
- Added Bowls of Cooked Rice
  - Bowls of Cooked Rice restore 5 Hunger Points and 5 Saturation and are crafted from 1 Rice Grain and a Bowl
  - They're designed to be a quick, easy, and reliable food to craft and eat once a player has a stockpile of ingredients
- Added Bowl of Fried Rice
  - Bowls of Fried Rice restore 7 Hunger Points and 8 Saturation and are crafted from a Rice Grain, an Egg, an Assorted Seasoning, a Carrot, and a Bowl
  - It's an improved version of a Bowl of Cooked Rice that, although requiring more ingredients, is fullfilling and healthy
- Added Ominous Cookies (thanks Ibby!)
  - The Ominous Cookie is crafted from a Cookie and 4 Assorted Seasonings together. Similarly to Monster Mash, the item has a chance to do something "weird" when consumed
  - It's recommended that players do NOT consume the item if they don't have a way or map back to where they came from, as they may find themselves lost and disoriented. It has a lower chance of activating when a player consumes it near their spawnpoint, but that chance is NOT zero
  - It is, however, very filling since it restores 8 Hunger and 9 Saturation
- Added Marshmallows, Marshmallows on a Stick, and Roasted Marshmallows on a Stick
  - Marshmallows are a light, fun snack that restores 3 Hunger Points and 1 Saturation, and can be eaten at any time due to their size (and make a gooey sound when eaten)
    - They can be crafted from an Egg, Water Bucket, and either Sugar or Honey Bottle
  - A Marshmallow on a Stick is crafted the same way, but includes a stick in its Recipe
    - On its own, a Marshmallow on a Stick has the same stats as a regular Marshmallow, however they can be cooked on a Campfire by crouching for 3 seconds in front of one to create a Roasted Marshmallow on a Stick
	- There are other blocks that can cook Marshmallows on a Stick faster: Fire/Campfires (normal speed), Soul Fires/Soul Campfires (faster speed), and Lava (almost instant)
  - A Roasted Marshmallow on a Stick restores 5 Hunger Points and 3 Saturation, and can still be eaten at any time
    - If a Roasted Marshmallow on a Stick is in a player's mainhand, and 2 Wheat Crackers are in their offhand, they can hold crouch to combine the two into a Marshmallow Sandwich
	- The system for doing this may be confusing--pressing crouch once will remove one of each item from the inventory and give the player an Unassembled Marshmallow Sandwich. Simply hold that item in the mainhand and another Wheat Cracker in the offhand to finish the Sandwich
- Added Wheat Crackers
  - Wheat Crackers are a light snack that restore 3 Hunger Points and 2 Saturation, and can be eaten whenever
  - They can be crafted using 3 Wheat, Vegetable Oil, a Water Bucket, and Assorted Seasoning which yields 6 Crackers
  - Wheat Crackers can also be manually combined with a Roasted Marshmallow on a Stick to craft a Marshmallow Sandwich (Wheat Crackers in offhand, then hold crouch)
- Added Marshmallow Sandwiches
  - A Marshmallow Sandwich is a unique item that can only be crafted by hand, and restores 8 Hunger Points and 5 Saturation. However, players must be hungry to eat them
- Added Charcoal on a Stick
  - Be careful when trying to roast a Marshmallow on a Stick! If a player keeps close to a Campfire for too long, their Marshmallow on a Stick will quickly turn into nothing more than an (almost) inedible lump on a Stick
  - Charcoal on a Stick restores 1 Hunger Point and 0.5 Saturation... but seeing as it's literally Charocal on a Stick, it's better used as furnace fuel
- Added Beef Burgers
- Added Cheeseburgers
- Added Impossible Burgers
- Added Fillet Burgers
- Added Chicken Burgers
- Added Farmer's Delight Burgers
  - Burgers are very filling foods that aren't very healthy. A player consming one may find that, although their Hunger Bar fills quickly, their Health doesn't regen as much after eating them unless they manage to eat at least two of them
  - All Burgers have 2 Bread in their recipes--acting as the buns--but each burger has other unique ingredients that the recipe book will keep track of
- Added Garlic Bread
  - I'll admit that I'm surprised it took me this long to add Garlic Bread. Regardless, Garlic Bread is crafted from 1 Bread, 1 Assorted Seasoning, and 1 Vegetable Oil
  - It restores 7 Hunger Points and 8 Saturation and 30 yummy and awesomeness points
- Added French Toast
  - Despite not actually originating in France, French Toast is a simple food that can be created quickly using a few ingredients most players will have in their food chests
  - It's crafted from 1 Bread, 1 Egg, 1 Milk, and 1 Assorted Seasoning. Consuming it will restore 7 Hunger Points and 8 Saturation
- Added Chocolate Milk
  - Chocolate Milk, crafted from 3 Cocoa Beans and 1 Milk Bucket, functions identially to a Milk Bucket. However, it will only clear NEGATIVE effects from the player
    - Just like Milk Buckets, this item will not restore any Hunger or Saturation when used
  - Players can consume Chocolate Milk to safely remove any effect that debuffs them without having to worry about losing any postitive effects they may have, such as Regeneration or Absorption
  - The negative effects removed are based off of a new mob effect tag list called `rmf:negative_effects`, which can be edited in this data pack or by other data packs to add or remove effects
- Added Poutine (thanks 0385mrcoolman!)
  - Supposedly a popular dish in some mystical place called "Quebec", it's crafted from 1 Potato, 1 Cheese, and 1 Mushroom Stew
    - The Bowl from the Mushroom Stew is not returned when crafting it, but is instead returned after eating it
  - Consuming Poutine restores 8 Hunger Points and 8.2 Saturation, and may come with a strange urge to say "C’était délicieux!"
#### Items
12+ new items have been added in this update:
- Added the Mortar & Pestle
  - The Mortar & Pestle is used to crush up various foods, and is used alongside the Shaker Cup to create new drinks. A list of valid foods can be found on the [wiki](https://github.com/regfunkid/reg-more-foods/wiki/Mortar-&-Pestle)!
  - To crush any valid food, hold the Mortar & Pestle in the offhand and the food in the mainhand. Then, hold crouch for a few moments and it will be converted into a new item
- Added the Shaker Cup
  - The Shaker Cup is used with the items the Mortar & Pestle creates to craft Smoothies, Berry Jams, and some extra drinks. It also has its own [wiki page](https://github.com/regfunkid/reg-more-foods/wiki/Shaker-Cup)!
  - The Shaker Cup allows for multi-step crafting and works similarly to the Mortar & Pestle: hold it in the offhand, and a valid item in the mainhand. Then, crouch to insert it into the cup
    - The Shaker Cup cannot be emptied until the recipe inside has been completed
  - After all ingredients have been inserted in the right order, it will display the recipe it's about to craft. To finish crafting, hold the container item it requires in the mainhand and crouch
   - Smoothies require a Glass Bottle to "pour" into, and Berry Jams require a Bowl
- Added several new "Mashed" item varients of existing foods
  - "Mashed" items are obtained by grinding valid items in the Mortar & Pestle. Mashed items on their own do not serve any function besides being added into the Shaker Cup to create drinks, and cannot be eaten once mashed
  - The only exception to this is Coconut Chunks, as grinding Coconut Chunks creates Coconut Mash. Coconut Chunks can also be consumed as a food themselves
- Added Rice Grain
  - Rice Grain can be obtained from Sniffers digging through blocks (which drops 1-2 Rice Grains), or from brushing through Suspicious blocks
  - Rice Grain is a required ingredient for any rice-related dish, as one may expect
  - Rice Grain can be crafted from 1 Rice Grain and 8 Wheat Seeds
    - If the tools to do so are provided by Mojang in the future, I will add a better method of gathering Rice Grain. In the meantime, this is how you collect it in this pack
- Added Pasta (thanks ryanjayaswal!)
  - Pasta is crafted from 3 Wheat, 2 Eggs, and a Water Bucket
  - As one would imagine, any pasta-related recipes such as Mac & Cheese will now require Pasta as an ingredient. Recipes involving pasta will be added in the future, but for now it's available to craft in this update
- Added Assorted Seasoning
  - Assorted Seasoning (crafted from a Mushroom, Sugar, Gunpowder, and a variety of plants) is a multipurpose item. It fulfills the role of being whatever spice or seasoning is needed for the recipe it's in, and will be required for the more filling foods
  - Following the introduction of this item, several foods will now require Assorted Seasoning in their recipes
  - The variety of plants required for the recipe are kept in a new item tag called `rmf:herbs` which can be directly edited to add, change, or remove ingredients for recipes using the tag
    - The "herbs" in the item tag were chosen from the flowers that grant positive potion effects as Suspicious Stew ingredients--because of this, not all flowers in the game are "herbs"
- Added Vegetable Oil
  - Vegetable Oil, like Assorted Seasoning, is a crafting item that is made from multiple seeds. It will also be required for the recipes of the more filling foods
  - Like its real life counterpart, it *is* technically consumable but it's probably a bad idea to drink 255mL of it at once
- Added Barrels of Water
  - Using 7 of any Wooden Slab and a Water Bucket will now create 3 Barrels of Water. The purpose of it is to act as a stackable variant of regular Water Buckets for recipes that require them
  - It was added due to the issue that trying to craft a lot of an item that requires Water Buckets in its recipe tends to get very annoying. Now, players can create many of Barrels of Water to use for blocks like the Crafter to automatically craft foods for them
- Added Barrels of Milk
  - Barrels of Milk are the Milk version of Barrels of Water, created for the same reason
  - It's crafted the same way a Barrel of Water is (except using Milk instead of Water), crafting 3 Barrels Of Milk
  - Barrels of Milk can also be consumed like Milk Buckets, effectively making them stackable Milk Buckets whenever needed
- Added Chef's Hats
  - Chef's Hats do nothing and offer no protection, but they make you feel like a real culinary genius!
  - They are crafted with 5 Wool and a Leather Helmet
- Added Cleavers
  - Cleavers have 150 durability, and naturally come with Looting 2 when crafted
  - They are crafted from 4 Iron Ingots and a Stick, and is used for a few block interactions besides being used as a weapon (or a decoration for your kitchen!)
    - If you're feeling silly, you can manually place a Cleaver on your head... which hopefully won't cause any minor headaches
- Added Rotten Tomatoes
  - Rotten Tomatoes have a 2% chance of dropping from Tomato Crops when broken, and can be thrown at mobs and players for laughs (neutral mobs will not find it humourous and will try to kill you)
  - One hot-headed mob in particular does not find Rotten Tomatoes very funny at all--ensure you kill this entity with a Rotten Tomato for a Hidden Advancement!
#### Features
- Cacti now damage players who break it with an empty hand
  - This one was more of a funny idea I had. But hey! You get an advancement for it. :3c
- Players eating Cake Blocks now play a "munch" sound for each slice eaten
- Cake Blocks will now drop Cake Slices when mined with a Cleaver, based on the number of slices already eaten
  - An edit has also been made to how Cake drops itself when mined. If a Cake Block has had a bite taken out of it, and is mined without using a Cleaver, it will drop itself with an indicator of how many bites have been taken out of it
    - This indicator is also displayed in the tooltip of the item
  - Cakes that indicate how many bites have been taken out of them each have a stack size of 4, but they can all still be mined with a Cleaver afterwards to gain the remaining bites as Cake Slices
  - This does *not* apply to Cake Blocks with a Candle on them--mining said Cake Blocks will only drop a Candle. Instead, players should eat a slice first to convert it back into a regular Cake Block, which can then be broken for slices
- Players eating Cake Blocks will now gain the Speed Effect
  - This boost lasts much longer than eating a regular Cake Slice--2 Minutes of Speed I rather than a Cake Slice giving 5 Seconds of Speed I
    - This is to encourage players to keep Cake at home or at a base so they can move around more, as well as encouraging them to bake more Cakes in the first place
- All custom items now include the name of the data pack in their tooltips
  - This is to help players see what the project actually adds, and help modded users know what mod in particular added what item (as all of the custom foods would otherwise be labled with "Minecraft")
- Crafted Campfires, when placed on the ground, no longer start already ignited: they must now be manually activated
  - They will, however, now drop themselves when broken. They will also now remember if they were ignited before being broken and place themselves ignited if they already were
  - This one was also a funny idea I had. Maybe more annoying than funny, actually. But I liked it, and starting campfires isn't particularly hard to do, so here it is
- Goal Advancements will now give players 10 Experience Levels when reached
- The "The Gourmand" advancement will now give players 30 Experience Levels when reached
#### Advancements
24 new advancements have been added in this update:
- "Wake Up and Grind" for obtaining a Mortar & Pestle
- "Barista Training" for obtaining a Shaker Cup
- "Shaken, Not Stirred" for crafting a drink using the Shaker Cup
- "The 21-Day Smoothie Diet" for crafting every type of Smoothie
- "The Forager" for finding a new fruit or berry added by Reg's More Foods (Silent Advancement)
- "A Berry Nice Find" for finding a new berry in the grass of a biome that has one
- "The Original Grain" for obtaining Rice Grain
- "Yeouch!" for mining a Cactus with an empty hand
- "Higher Brain Activity" for mining a Cactus with a Cactus
- "Just Peachy" for obtaining a Peachy
- "A Spiky Apple?" for obtaining a Prickly Pear
- "It's Not Jammed, Is It?" for crafting any Berry Jam
- "11% Tomatometer Score" for killing a Blaze with a Rotten Tomato (Hidden Advancement)
- "...Eww" for obtaining a Poisonous Potato or Rotten Tomato
- "Golden Side-Grade" for crafting a Diamond or Emerald Apple
- "Mildly Overpowered" for crafting an Enchanted Diamond or Emerald Apple
- "The Spice of Life" for obtaining Assorted Seasoning
- "Chef's Kitchen" for obtaining a Mortar & Pestle, Shaker Cup, a Chef's Hat, and a Cleaver
- "Roasted To Perfection" for successfully roasting a Marshmallow on a Stick over a Campfire
- "Legally Distinct Sandwich" for crafting a Marshmallow Sandwich
- "Charred To Perfection" for consuming a Burned Marshmallow on a Stick
- "The Burger With A Smaller Burger In It" for crafting a Farmer's Delight Sandwich
- "Saving The Leftovers" for obtaining a Cake with any amount of bites left in it
- "Beware The Cookie's Crumbles" for consuming an Ominous Cookie
#### Misc
- Added framework for Translation Files
  - Currently, the only supported language is English(US), but more can now be added in the future by copying the `en_us.json` file and rewriting all item names in a different language
  - Several item names and advancement text have also been updated slightly
- Added "info" files to the data pack folders for anyone reading through them
  - These info files should hopefully give insight into my decisions when building the project, as well as explaining the purpose of various files and folders
- "The Gourmand" advancement now tracks (and requires) every kind of Snow Cone, instead of just Red Snow Cones
  - sorry
- The "Hey, That's Ours!" advancement now requires that a player cooks the Honeycomb first before they eat it
  - Shearing it from a nest/hive is also still required, it just has to be cooked now
### Changed
#### Foods
- Nerfed "Fish & Chips" by increasing the time to eat to 2.7 seconds (from 2 seconds)
  - It now also requires Assorted Seasoning in its recipe
  - This was done to *hopefully* make it a bit more balanced as it's a relatively early game food. I wanted to avoid editing the food values, so these two changes should make it more fair since it's very easy to farm and forget
- Renamed "Cheese Sandwich" to "Grilled(?) Cheese Sandwich"
- Nerfed the Burrito food(s) slightly
  - The Burrito recipe(s) now output 1 Burrito instead of 3
    - This change was made to make Burritos less OP of a food, as 12 Hunger Points and Saturation on-command is very strong to have for the relatively cheap cost of its recipe
    - Veg Burritos were also affected by proxy of this change, since I don't want to make veganism a "meta" choice in comparison
- Nerfed Sheperd's Pie slightly
  - The recipe now outputs 3 pies instead of 6
    - Even though the recipe is annoying to gather the resources for, the items required themselves are easy to farm, making this a powerful item once a little prep has been done. This change makes it take a little more effort to just craft a stack of Sheperd's Pies
- Cereal can no longer be eaten at any time
- Chicken Parmesan now takes 3.22 seconds to eat (from 3)
  - It now restores 8 Hunger Points (from 10)
  - It now restores 9 Saturation (from 12)
  - The texture has also been updated to look a little less garbage
  - It is now a "Bowl" Food
  - It has been renamed to "Bowl of Chicken Parmesan"
  - The recipe now gives 2 Bowls of Chicken Parmesan
- Grilled Cheese Sandwiches now take 2 seconds to eat (from 1.6)
- Reduced the Hunger Points of Fried Sniffer Eggs to 12 (from 16)
- Fruit Punch can now be consumed at any time
- Tweaked Glazed Donuts slightly
  - The duration of Haste given from eating it has been increased to 5 seconds (from 3)
  - The duration of Speed given from eating it has been increased to 10 seconds (from 6)
  - Both effects only have a 60% chance to appear when eating it
- Kabobs no longer have a "damage indicator" of how eaten they are
- Each level of Kabob can now be stacked up to 3 times in the same slot
- Made changes to Mac & Cheese:
  - It no longer displays particle effects when eaten
  - The amount given per recipe has been reduced to 1 (from 3)
  - The recipe no longer requires Wheat-- only 1 Cheese, 1 Pasta, and a Bowl
- Ramen no longer displays particle effects when eaten
- Salad now restores 4 Hunger Points (from 3) and 3 Saturation (from 1)
- Made changes to Yogurt:
  - Yogurt now restores 7.5 Saturation (from 7.2)
  - Yogurt now applies the Health Boost effect for 2 minutes when consumed (it's healthy!), granting an additional 2 hearts. These hearts will be removed if the effect runs out or is cleared, and can stack with Absorption
- Tomato Sauce can now stack up to 64 items (from 8)
- Cheese can now be found in Non-Ominous Trial Chamber Spawners
- Roasted Carrots can now be cooked in Furnaces and Campfires instead of only Smokers
  - The point of the data pack is to add more food options, not to make getting food slightly annoying or restrictive. Thus, I've made this change to make it easier to craft them
- Renamed Hearty Stew to "Bowl of Hearty Stew"
- Renamed Sheperd's Pie to "Bowl of Shepard's Pie"
- Renamed Pumpkin Pie Slice to "Slice of Pumpkin Pie"
- Renamed Pumpkin Slice to "Sliced Pumpkin"
#### Recipes
- The following recipes are now Shapeless (can be crafted without a Crafting Table)
  - Mac & Cheese
  - Apple Juice
  - Apple Pie Slice
  - Honeyed Apple
  - Sea Snack
- Honey Garlic Chicken no longer uses Gunpowder and Sugar in its recipe
- Cake can now be crafted using Barrels of Milk as well as Milk Buckets
- The recipe for Tofu has been adjusted
  - It now requires one of four items instead of Bones: Egg, Apple, Kelp, Seagrass
  - The ingredients listed are kept in a new item tag called `rmf:tofu_ingredients` which can be edited to directly add, change, or remove the ingredients required for the recipe
- Both types of Hot Dogs have had their recipe shapes changed slightly
  - The recipe is now diagonally shaped
- Bamboo can no longer be used as an ingredient for Salad
  - Apparently, raw Bamboo is actually toxic, and should be cooked or otherwise prepared first. Even though Minecraft is not a realistic game, I don't want to make people think you can eat raw Bamboo. You learn something new every day I guess
#### Advancements
- Recipe advancements will now only grant recipes if a player has the hardest or most unique ingredient required for the recipe
  - If all ingredients are equally easy or difficult to obtain, collecting any of them will grant the recipe
    - For example, The Burrito recipe will now only be granted if a player has Cheese, which is harder to obtain than the other ingredients in the recipe like Mushroom Stew. The Brownie recipe will only be granted if a player has Cocoa Beans, which is more unique than Sugar and Wheat
  - Recipes will still be granted regardless if a player crafts it, even if they somehow don't have the recipe in their Recipe Book
- Updated the description of the "Cooking For Dummies" advancement
  - It now shows what the player has to do to obtain the Gourmand's Digest
- Updated the description of the "Cranking Up The Heat" advancement
  - It now more clearly shows what the player must do to reach the advancement
- Updated the description of the "A Multipurpose Snack" advancement
  - It now more clearly shows what Honeyballs are used for
- Updated the description and conditions of the "A Balanced Breakfast" advancement to include any type of Milk
  - It will now also check for Milk Bucket, Barrel of Milk, or Chocolate Milk items
- Moved the "Quite Appealing" advancement to be under "The Forager"
- Moved the "Cookie Enthusiast" advancement to be under "Extra Dietary Options"
- Changed the descriptions of some advancements
  - Sorry this is vauge, but I forgot to document all the changes as they were pretty small (like changing the spelling or moving words around)
- Changed the requirements of the "Lil' Sundial" advancement
  - It now requires that the player is crouching while holding the clock, to match with the change made to the time check system
- All "Goal" advancements now have colored description next
- The following advancements are now considered "goals" instead of "tasks":
  - "Drinkoholic", "The 21-Day Smoothie Diet", "(Most) Colors of The Rainbow"
- Changed the "Accidental Alchemy" advancement in a few areas:
  - It now also triggers when crafting a Snow Block using Rotten Tomatoes
  - It now tracks the `[item_model]` instead of the `[custom_data]` component of the items inside it
  - It is now a Hidden Advancement, and is placed under the "Extra Dietary Options" advancement
  - It no longer shows in chat when the advancement is reached
  - It is now called "...Wait, What?" and its description has also been changed
    - The filepath and filename for the advancement have not been changed
	- It should be noted that when Mojang eventually update data packs to be able to add their own Namespaced IDs, this advancement will be removed as the reason it exists is because Namespaced IDs don't
- Updated the "Totally Grainular!" advancement
  - It now also requires consuming Garlic Bread and French Toast
  - It is now a Goal advancement
#### Data & Misc
- Changed the "dummy items" of all drinks and bowl-foods
  - The reason for this is due to Snapshot 24w34a allowing for more customization with food items, namely being able to affect the sound of items being consumed. This single addition fixes a number of issues with the pack, killing several birds with one stone. The foods affected will be automatically updated in player's inventories
- Changed the ```pack.png``` of the packs again
  - The `pack.png` of the last update was smooshed and looked ugly :(
- Change the icon of the `root` advancement to match the `pack.png`
- Edited the `CHANGELOG.md` file slightly
- Edited the `tick.json` file for the `rmf` namespace to clean it up
  - Thanks to Soul (iamsoul) on Discord for pointing this out for me!
- Changed how the time checking system works with Clocks
  - Players now need to hold the clock (mainhand or offhand) and hold crouch at the same time
    - This should help prevent important actionbar text from being obscured by the current daytime
- Replaced the `[custom_model_data]` of all item textures to prevent overriding other data packs
  - This is a pretty big change, and for this update I've added a function that *should* automatically convert any affected items into their new variants
    - Any changes made to affected items (such as renaming them in an anvil, somehow enchanting them, etc) will be removed by their new versions (the function deletes old items and replaces them)
    - I have no doubts that I made a mistake somewhere with my shoddy code, so PLEASE send me a bug report to the issue tracker (available on the Modrinth page or bottom of the changelog) if you find anything remotely off
- Changed the way all advancements detect items
  - Advancements will now detect items by using their `[custom_data]` values rather than their old `[custom_model_data]`
    - This was done to make it easier to create new advancements without needing to remember the specific texture number of an item (especially since I've done away with the system entirely), as well as making it easier to tell what the advancement is tracking since all you would have to go with before was just a number. Now, advancements will show the exact item id of what they are tracking
- Changed the names of all scoreboards to include the data pack's namespace
  - This was done for the same reason as the `[custom_model_data]` and the `item_id` were changed for: compatibility with other data packs
    - It would've been REALLY nice if i'd done this like 3 updates ago but we live we regret and we learn
  - Doing this also removes the old versions of these scoreboards of all players, so the function that handles fixing this will remain next update as well just in case you have any friends who may miss logging in for this update (as they would've missed the function that fixes the scoreboards)
- Reduced the chance of obtaining a Dragon Egg from killing an Ender Dragon to 30% (from 40%)
- All foods now have an additional Component in their recipes and data--`minecraft:consumable`
  - This change was made due to Snapshot 24w34a changing how the food component worked: it no longer makes items edible by default, it simply applies the nutritional benefits. `minecraft:consumable` is now required to actually make them edible
- Renamed some item textures:
  - `apple_cider` is now `apple_juice`
  - `churro_3`, `churro_2`, and `churro_1` are now `churro`, `churro_one_bite`, and `churro_two_bites`
  - `honey_apple` is now `honeyed_apple`
  - `kabob_3`, `kabob_2`, and `kabob_1` are now `kabob`, `kabob_one_bite`, and `kabob_two_bites`
  - `veggie_quesadilla` is now `veg_quesadilla`
- The item id for Honeyed Apples is now `honeyed_apple` (from `honey_apple`)
- Item `[custom_data]` tags now match their texture file names (except for snow cones)
  - Example: both the filename and `item_id` of the Veggie Quesadilla is now `veg_quesadilla`
- Changed the Item ID for Roasted Carrots to `roasted_carrot` (from `cooked_carrot`)
### Config
- **Changed the commands for configuration options**
  - Instead of giving players a book with config options, players can now use `/function rmf:_config/(command)` to find the option they wish to edit
  - Config commands now also come with a "help" function that explain how to use the Command
    - An example of this is `/function rmf:_help/give_item` which can tell players how to use the `rmf:give_item` function
  - The original Config Book has been removed
- Added a new config option for setting how fast players can use the Mortar & Pestle, in game-ticks
  - The speed can be any number from 5-40, with the default being 20 ticks (1 Second)
- Added a failsafe for the `rmf:grindingCooldown` score that activates upon reaching the `root` advancement
  - The failsafe catches the possible situation where a player joins a server after the `/load` command has been run (or the pack has been loaded). In this situation, that player would not have any `grindingCooldown` score, preventing them from being able to use the Mortar & Pestle
- Added a tracking score to prevent resetting all config options when reloading the data pack with `/reload`
- Added a reset function to manually reset all scoreboards added by Reg's More Foods
- Added a recipe function to manually grant a player all (crafting) recipes added by Reg's More Foods
  - Individual recipes can still be given by using the `/recipe` command
- **Changed the command for giving custom items**
  - The command is now `/function rmf:give_item/(item_id) {player:(...),count:(...)}`
  - The command now *requires* that the user specify the who is recieving the item, as well as how many of the item they wish to give, using an 2 new arguments called `{player}` and `{count}`
    - An example of this would be `/function rmf:give_item/apple_juice {player:regfunkid,count:3}` to give regfunkid 3 Apple Juices, or `/function rmf:give_item/burrito {player:"@a",count:4}` to give all players 4 Burritos
	- `{player}` does not need to be a username--it can also be a target selector (like `"@p"`, `"@a"`, etc.)
	  - The value of `{player}` *cannot* be an entity/mob, it must be a valid player or else the function will fail
  - This change was made to make giving players custom items much easier to understand, as I noticed others were getting confused with the correct command syntax
- Added the Item ID of all custom items to their recipes and /give commands
  - All items now include the namespace of the pack in their Item ID (Eg. `rmf:apple_pie`)
    - Originally, this was to further help with compatibility with other data packs, but snapshot 24w36a came out with `[item_model]` while this was being developed which makes this entire change redundant (for the sake of documentation, I will still explain what it does)
    - It allows players to detect custom foods in this pack, whether that be for a command or advancement or function for their own data packs (for example, `/clear regfunkid *[custom_data~{item_id:"rmf:apple_pie"}] 3` will clear regfunkid of 3 items with the `rmf:apple_pie` item id)
	- The reason the command is `[custom_data~{}]` and not `[custom_data={}]` is because the command with a `=` sign will ONLY look for items that match the requirements specifically-- adding a `~` sign will make the command work as long as the item has one of the requirements
	  - If you don't feel like typing the entire `[custom_data]` specification, you can always use `[item_model]` to directly reference an item since every item has its own model file (even if the textures are identical)
	  - Once again, this is for data pack compatibility. In the future, I will have a Data Pack API that I plan to merge with this project, and it will apply new data tags to most items. This change is preparing for that, so I don't have to do it later
### Removed
- Removed the Config Book
- Removed food values for Coconuts, Honeycombs, and Berries (Sweet Berries and Glow Berries)
  - Honeycombs can now be cooked to create Honeycomb Candy, and Coconuts and Berries can be processed in a Mortar & Pestle to create either new foods or ingredients for new foods.
  - Berries already had their own default food value that was edited in Reg's More Foods. This change simply removes the edit made to them (so, they can no longer be eaten much faster than other foods, and no longer have increased Hunger Points values)
  - Exising versions of these items will not be automatically updated--if they were in your world before this update, they can still be interacted with like the newer versions
- Removed the lore text for Honeyballs
- Removed the `rmf:bg/item_refund` file as it was a duplicate of an already existing file
- Removed the recipe and recipe advancements for the vanilla "Rabbit Stew" recipe
  - I removed it because I also replaced the recipe for Rabbit Stew with a version with easier-to-obtain ingredients, as well as tweaking its food values slightly
- Removed the model files under the `minecraft` namespace in the data pack
  - 24w36a's `[item_model]` component makes my old `[custom_model_data]` system redundant. Although it does still have its uses, I won't be needing it for this project and so the files are not needed anymore
  - Any files still tracking items by their `[custom_model_data]` now do so using this new component
- Removed the Max Stack Size from most foods
  - Even though I wanted to balance the stronger foods by restricting how many of them a player can hold at once, I ended up seeing the restriction as just annoying, since you could still hold a stack of the item in different slots. The goal was to encourage players to make other foods--not to inconvience people. For the time being, the stack sizes have been removed
    - There are a few exceptions to this: Popcorn still has a Max Stack Size of 1, and the two new items added (The Mortar & Pestle and Shaker Cup) both have a Max Stack Size of 1
### Depreciated
- Replaced the `[custom_model_data]` system for a new one that utilizes Snapshot 24w36a's `[item_model]` component
  - This change was made to ensure that anyone who installs my data packs won't have any other data packs they have installed be affected or broken by mine-- essencially, this change was made for compatibility
  - Originally, I was going to just replace the old `[custom_model_data]` with a different system that adds my own numerical ID to prevent overriding other data packs, but then that 24w36a came out and made everybody's lives 8 times easier. Thanks Mojang!
  - A repeating function has been created to *hopefully* automatically replace affected items, but there are no promises I didn't make a mistake somewhere so let me know if you find any (and the function will be removed in the next update for lag prevention)
- All drinks and "bowl" foods have had their dummy items changed to Firework Stars
  - Because of the addition of `[minecraft:consumable]` from 24w34a, consumable items can now have custom sounds played. This allows me to just group together most of the foods under 1 dummy item. During gameplay, nothing has changed, as the items are being automatically updated by the function I created anyways
  - If you happen to use any "JEI"-type mods in your world or server, you can find all the foods, drinks, and bowl items under the Firework Star item. Any crafting ingredients can be found by looking up their names (example: "Pasta", "Barrel of Water", "Assorted Seasoning", etc)
### Fixes
- [RMF-16](https://github.com/regfunkid/reg-more-foods/issues/16): The `rmf:tick` function isn't optimized with the newest version of the pack 
- [RMF-21](https://github.com/regfunkid/reg-more-foods/issues/21): Crafting Snow Cones don't return the Powdered Snow Bucket used to craft them
- [RMF-22](https://github.com/regfunkid/reg-more-foods/issues/22): Eating Mushroom Stew doesn't return the bowl used to craft it
- [RMF-26](https://github.com/regfunkid/reg-more-foods/issues/26): Custom drinks can be used as Honey Bottles

### Bugs
- [RMF-27](https://github.com/regfunkid/reg-more-foods/issues/27): All items use the Firework Star graphic instead of the custom ones
  - This issue seems specific to one version of the pack that can be found from the ATLauncher, a launcher than Reg's More Foods isn't naturally available on. Until I can find what exactly causes this issue or how to fix it automatically, it will remain a bug

## [1.1.2] - 2024-9-2

### Changed
- Apple drops have been tweaked a bit
  - The highest chance of getting an Apple from a leaf block has been dramatically reduced to 5% (from 15%)
  - The minimum amount of Apples that can drop from a leaf block is now 1 (from 2) and the maximum is now 2 (from 5)
    - Side note: what the hell was i huffing when making the maximum 5?! at 15% PER BLOCK!?
- Reduced the chances of finding Coffee Beans in Jungle Leaves to 2% (from 5%)
  - Coffee Beans are only used for 1 recipe at the moment, they don't need to be so common at all
### Misc
- Added an "Install Instructions" file to the data pack download zip folder
- Removed the "Unreleased" area from the changelog
  - I'd rather not show exactly what I'm planning on adding, since things change easily and I may decide not to add something due to difficulties. Plus it's fun to see what gets added!

### Fixes
- [RMF-17](https://github.com/regfunkid/reg-more-foods/issues/17): Zombie mobs always drop carrots, iron ingots, and potatoes
- [RMF-24](https://github.com/regfunkid/reg-more-foods/issues/24): Apples drop too frequently from trees
- [RMF-25](https://github.com/regfunkid/reg-more-foods/issues/25): Enchanted tools make leaf blocks that have custom food drops drop themselves

## [1.1.1] - 2024-7-25

### Fixes
- [RMF-18](https://github.com/regfunkid/reg-more-foods/issues/18): Some Minecraft advancements ignore Tropical Fish and Poisonous Potatoes
- [RMF-19](https://github.com/regfunkid/reg-more-foods/issues/19): Shipwrecks occasionally have poisonous Tofu items
### Bugs
- [RMF-20](https://github.com/regfunkid/reg-more-foods/issues/20): Expert Fishermen Villagers buy Cheese named "Tropical Fish" 

## [1.1.0] - 2024-6-14

### Added
#### Foods
- Added Ramen (Thank you Hans and Timothy!)
- Added Shepard's Pie
- Added Grilled Cheese Sandwiches (Thanks Jack!)
- Added Honey 'Garlic' Chicken
- Added Hot Dogs
- Added Veggie Dogs
- Added Perogies
- Added Tea
- Added Coffee
- Added Roasted Carrots
  - Carrots can only be roasted using a Smoker or a Campfire (cooking it in a furnace would burn it silly)
- Added Snow Cones
  - Snow Cones are foods that come in a variety of colors, but all restore the same amount of food and saturation. The colors available are: Red, Black, Blue, Green, Light Blue, Lime, Orange, Pink, Purple, White, and Yellow. Making these were a pain in the a## and it isn't even all the colors in the game
  - Only the RED Snow Cone is required for the "The Gourmand" advancement, so you don't need to eat all 11. You're welcome.
  - Additionally, only the Red Snow Cone is tracked for the "Extra Dietary Options" advancement, so crafting any other color of Snow Cone won't activate it
- Added Lasagna
- Added Chocolate Cake (slices)
- Added White, Milk, and Dark Chocolate Bars (Thanks G4act1co!)
- Added Churros (Thanks again, G4act1co!)
  - Churros behave like Kabobs, where eating one creates a new, smaller Churro with slightly less Hunger Points and saturation values
- Added Quesadillas
- Added Veggie Quesadillas
- Added Croissants
- Added Brownies
- Added Mac & Cheese
- Added Popcorn (A highly requested addition, thank you everyone!)
- Added Chicken Noodle Soup (Thanks StarWarsBlaster!)
- Added Chicken Parmesan (Thanks Eric!)
  - I won't lie, the Chicken Parmesan texture is... iffy. It will likely be changed in a later update
- Added Baguettes (Thanks Makenna!)
#### Items
- Added Coffee Beans
  - Coffee Beans can be sourced from breaking Jungle Leaves or Short Grass/Ferns in Jungle Biomes, and are required to make Coffee
#### Advancements
The following advancements have been added:
- "Iron Belly" for eating Rotten Flesh while at 0 Hunger Points
- "Drinkoholic" for consuming all available Drinks
- "(Most) Colors of the Rainbow" for eating every available color of Snow Cone
- "Locally Sourced" for finding Coffee Beans in Jungle Trees or in Jungle Grass/Ferns
- "Soy To The Rescue!" for crafting Tofu
- "Nature's Acidic Apples" for obtaining Tomatoes from either a Village or the Tomato crop
- "The Perfect Assembly" for crafting an MCT Sandwich
- "Lil' Sundial" for holding a Clock in either the Mainhand or Offhand to track the time
- "A Balanced Breakfast" for consuming a Bowl of Cereal, any bottled drink, and either a Banana, any Fried Egg, Apple, or Croissant between 6 AM and 11 AM (in daytime)
- "Watching The Show" for eating Popcorn inside a house while it rains or thunders outside
- "Totally Grainular!" for eating a Baguette, Croissant, Pretzel, Plain Donut, and Bread
- "Cookie Enthusiast" for eating a Honey Cookie, a Cocoa Cookie, both kinds of Berry Cookie, and a regular Cookie
#### Recipes
- Added a recipe for turning Tomatoes into Tomato Seeds
  - The recipe for creating Red Dye from Tomatoes has also been edited
#### Tags
- Added Melons and Pumpkins to the ```mineable``` tag for hoes, so they can now be mined faster with hoes
  - This gives an alternative way of mining melons quickly, as trying to do so with an axe will just break it into slices. Pumpkins don't share this trait--their "harder" exterior prevents them from being broken into slices by axe. Players still must do so at a Stonecutter like before
#### Misc
- Implemented a Changelog format based on keepachangelog.com. It's been edited slightly to better fit these updates, but it should vastly improve readability
  - Previous updates have also had their changelogs updated to fit the same format--did you notice?
- Added a changelog file to the download of the pack. So, you can easily see all the current changes as well as the past ones from any future version you install
- **Changed the namespace of the pack to ```rmf``` for "Reg's More Foods" (from ```morefoods```)**. Any commands that required typing in that namespace will now require ```rmf``` instead (example: ```rmf:a_balanced_breakfast``` advancement)
  - Previous references of the old namespace in changelogs will not be corrected, only future references will be
  - This could cause a lot of issues, so if you find any bugs please let me know!
- Created modded versions of the pack, so you can play it on Forge/Fabric/Quilt worlds or in modpacks now
  - A Forge version will be created when Forge actually updates to 1.21 (please)
- Zombies and Husks now drop Zombie Jerky and Roasted Carrots if killed with fire
  - This behaves the same way as how killing them with fire makes them dropped Baked Potatoes instead of regular Potatoes
- Various foods can now be found in loot chests
  - For example, Cheese can occasionally be found in Plains Villages (as well as Desert Temples), Red Snow Cones (specifically) can be found in Snowy Villages, and Bananas can be found in Savanna Villages
- Added a new system for tracking the daytime of the game
  - The time reads in 12 Hour format on the Actionbar (above the player hotbar), updating every "30 minutes" in game whenever a player holds a Clock in their Mainhand or Offhand
  - This was added to assist with the "A Balanced Breakfast" advancement, so players could tell exactly what time it was in the world
  - This functionality is *enabled* by default but can be disabled in the config settings
- **Added a new Food Classification System**
  - Foods are now classed as one of the following: *Entrées*, *Starters*, *Appetizers*, *Sides* and *Drinks*
  - Classifications aren't used in-game, but are referenced in Wiki pages as well as the Gourmand's Digest to help players know what to expect from any particular food they may not have eaten yet
### Changed
- Changed the ```pack.png``` of the packs
- Changed the system that Kabobs use to make them more seamless
  - They now use 24w19a's new ```food``` component system
- Updated Kabobs to be stackable (each level now stacks up to 3)
- Changed the filename for the changelog that you're reading right now to ```CHANGELOG.md``` (from ```changelog.txt```)
- Changed the folder name structure of the data pack to match with 24w21a's update
  - All data pack folder names have been updated to be of "singular" fashion: this means that ```blocks``` and ```functions```, for example, have now become ```block``` and ```function```. The only exception is ```tags```
- Moved several files around and added an ```rmf``` namespace for the resourcepack
- Changed the "A Redditor's Breakfast" advancement name to "A Light Breakfast"
  - The file name of ```redditor_breakfast``` has also been changed to ```a_light_breakfast```
- Edited the description of the "Extreme Dieting" advancement
- Moved the "Desperate Times" and "Extreme Dieting" advancements to be under "Iron Belly"
- Renamed the bowls of Ice Cream and Chocolate Ice Cream to just "Ice Cream" and "Chocolate Ice Cream"
- Changed the textures for Ice Cream and Chocolate Ice Cream, as well as their food and saturation values slightly
- Changed the way Ice Cream and Chocolate Ice Cream works as an item, meaning that previous versions of the item will be depreciated and likely have broken textures
  - If you had an older version of the pack in your world with Ice Cream in it, it will likely have a broken texture. Feel free to delete it by throwing it away somewhere. Or don't. I don't control you
- Renamed Yogurt to "Bottle of Yogurt"
- Renamed Apple Juice to "Bottle of Apple Juice"
- Renamed Fruit Punch to "Bottle of Fruit Punch"
- Made Apple Pie and Apple Pie Slices more bearable to look at (updated their textures)
- Updated the texture for Tomato Seeds and Tomatoes
- Updated the texture for the Tomato crop block (it looks like tomatoes are actually growing now!)
- Changed the icon for the "No Room For Seconds" advancement
- Tweaked the food and saturation values for the MCT Sandwich and Fish and Chips
  - At the previous values, Fish and Chips were almost as good as the MCT Sandwich. That was a problem because Fish and Chips are significantly easier to create and much cheaper. They have been edited to provide a little less nutrition and saturation while still being a good early game food item
  - The MCT Sandwich was also tweaked because the recipe, despite requiring either beating the game or challanging an Ocean Monument, was overpowered for its price. It now restores slightly less nutrition and saturation values, but it is still a powerful--if not the best--food item in the pack
- Reduced the amount of Pretzels gained per recipe to 1 (from 3) and changed its food classification to "Starter" (from "Snack")
  - Pretzels are a very easy food to farm given how they only require Wheat, and eating all 3 gained from crafting would yield 15 hunger points (7.5 bars) which is crazy. Rather than reduce the food value, I thought it would be better to reduce the amount of them gained per recipe
- Increased the nutrition and saturation values of Pretzels
  - Since I removed the main gimmick of Pretzels (being that despite being as filling as normal bread, you could make more of them and eat them whenever) I increased their food values to be a *bit* better than regular bread. For 2 extra wheat, you get 6 nutrition and 8 saturation than Bread's 5 nutrition and 6 saturation. However, Pretzels still take 0.2 more seconds to eat than bread
- Slightly reduced the nutrition value of Plain Donuts to 5 (from 6)
  - Due to all the changes made to Pretzels, there become no need to bother making them because Plain Donuts were cheaper to craft and also more filling. So, this was a necessary nerf. Don't worry, though! The recipe still yields 2 Plain Donuts per every 4 Wheat, totalling 10 hunger points per recipe
- Updated the "Edible Gold" advancement to include finding Cheese in chests as well as crafting it
- Updated the "Quite Apeeling" advancement to include finding Bananas in chests as well as from Acacia trees
- Changed the frame of the "(Most) Colors of the Rainbow" and "Drinkoholic" advancements to "task" (from "goal")
- Edited the description of the "(Most) Colors of the Rainbow" advancement
- Renamed Cereal to "Bowl of Cereal"
- Attempted to make Apples more common from Oak trees
- Tweaked the texture of Cheese
- Tweaked the texture of the Bowl of Cereal
- Updated "The Gourmand" and "Extra Dietary Options" advancements
- Tweaked the Apple Juice recipe to be shaped instead of shapeless
- Tweaked the Powder Snow Bucket recipe to be shaped instead of shapeless
- Tweaked the Apple Pie Slice recipe to be shaped instead of shapeless
- Grouped Apple Pies and Apple Pie Slices together in the Recipe Book
### Removed
- Removed the old Kabob use system's files to instead use 24w19a's new ```food``` component system, which allows for directly changing what item a food converts into 

### Depreciated
- Reworked the Bowl of Ice Cream and Bowl of Chocolate Ice Cream into "Ice Cream" and "Chocolate Ice Cream"
  - The old versions of these items will show as broken textures if they already existed in your world
  - The only way to deal with this is to simply throw the item away, put it somewhere, or otherwise destroy it

### Fixes
- [RMF-4](https://github.com/regfunkid/reg-more-foods/issues/4): Zombie Jerky doesn't apply hunger correctly
- [RMF-5](https://github.com/regfunkid/reg-more-foods/issues/5): Golden Apple Juice obtained from the /give command doesn't stack with crafted Golden Apple Juices
- [RMF-6](https://github.com/regfunkid/reg-more-foods/issues/6): Kabob moves to next available slot when used, instead of replacing mainhand
- [RMF-8](https://github.com/regfunkid/reg-more-foods/issues/8): Poisonous Potatoes from fully grown Potato crops appear as Tofu
- [RMF-9](https://github.com/regfunkid/reg-more-foods/issues/9): Tropical Fish dropped from fish and obtained by fishing appears as Cheese
- [RMF-13](https://github.com/regfunkid/reg-more-foods/issues/13): Eating a Bowl of Cereal doesn't give back the bowl used to craft it

### Bugs
- [RMF-12](https://github.com/regfunkid/reg-more-foods/issues/12): Snow Cones and Churros, for some horrid reason, are unable to stack together if the player is in Creative Mode 
  - This also affects Snow Cones and Churros obtained from the /give system, so they can't be stacked with their crafted varients either
  - This bug wasn't caused be me--it's a bug with Minecraft which i've reported [here](https://bugs.mojang.com/browse/MC-272969)
- [RMF-14](https://github.com/regfunkid/reg-more-foods/issues/14): Crafted Bowls of food don't stack with their variants obtained from the /give system

## [1.0.0] - 2024-05-01

### Added Features
#### Foods
- Added Bananas, which can be found in Acacia Trees
- Added Mangos, which can be found in Mangrove Trees
- Added Cheese Pizza Slices
- Added Veggie Pizza Slices
#### Items
- Added the Gourmand's Digest
  - A cookbook which acts as a mini in-game wiki. Currently has no functionality, will be given some in a later update
  - It can be crafted by cooking a Book & Quill in a Furnace
#### Recipes & Data
- Added a loot table to Cakes, so you can pick one up if no slices have been taken from it
- Added a new recipe for Frosted Pumpkin Pie so players can add frosting to already made Pumpkin Pies as well
#### Advancements
The following advancements have been added:
- "Quite Appeeling" for finding Bananas
- "Juicy Fruit" for finding Mangos
- "Vegan(?) Leather" for cooking Rotten Flesh into Leather in a Blast Furnace
- "Cranking Up The Heat" for smelting a custom recipe in a Blast Furnace, or obtaining a Blast Furnace
- "Hey, That's Ours!" for scraping Honeycomb from a Beehive or Bee Nest, and then eating it
- "Syrup, But From Bees" for obtaining a Honey Bottle
- "Cooking For Dummies" for obtaining the Gourmand's Digest
- "A Redditor's Breakfast" for eating a Cake, whole, without placing it down
- "No Room For Seconds" for being completely full (player saturation level is at 20)
- "Literally Starving" for being completely hungry (the hunger level is at 0)

### Changed
- Renamed "Pizza Slice" to "Meaty Pizza Slice"
- Renamed "Vegan Taco" to "Veggie Taco", and changed its texture
- Renamed "Fish Roll" to "Sea Snack", and changed its recipe as well as its texture and food value
- Edited Melons to drop Melon Slices automatically when broken with an Axe
- Edited the "MCT Sandwich" recipe to require wheat, instead of an outrageous amount of bread
- Edited the "Veggie Taco" recipe to not just require Tofu
- Increased the saturation of Melon Slices to 2.2 Points (from 1.2)
- Moved the "A Caveman's Breakfast" advancement under "Cranking Up The Heat"
- Moved the "A Multipurpose Snack" advancement under "Syrup, But From Bees"
- Renamed the "Conk!" advancement to "A Hairy Apple?"
- Updated the ```root```, "Extra Dietary Options" and "The Gourmand" advancements again (that's gonna be a recurring thing btw)
- Moved ```morefoods:campfire/leather``` to the ```blasting``` category (now ```morefoods:blasting/leather```)
- Changed the "Edible Gold" advancement filepath name to ```edible_gold``` (from ```crafted_cheese```)

### Removed
- Removed Cheese from the ```veg_burrito_ingredients``` tag due to recipe conflicts
- Removed ```morefoods:campfire/fried_egg``` from the ```root``` and "Extra Dietary Options" advancement requirements as there's no actual way to check for it, making it irrelevant

### Config
- Added a Config Menu
- **Added a new Give Command system!**
  - Type ```/give @p knowledge_book[custom_data={item_id:(item_id)}]``` to give any custom food
  - Custom food IDs can be found on the Wiki (after i add them), or using ```/function morefoods:config``` and clicking the "commands" button

### Known Bugs
- Golden Apple Juice from the give command doesn't stack with crafted Golden Apple Juices
  - I will try to fix this, but I honestly don't know what causes it and it's not exactly a huge issue. Maybe a future Minecraft update will fix this for me, who knows.

## [1.2.0-beta] - 2024-04-18

### Added
#### Recipes & Data
- Added a new Advancement category for the pack, as well as a background image
- Added a new recipe for Melon Seeds, so players don't need to cut a Melon in a Stonecutter first just to get seeds from the slices
#### Advancements
The following advancements have been added:
- "Edible Gold" for crafting Cheese
- "Desperate Times" for eating Zombie Jerky

### Changed
- Edited the Melon recipe to only require 4 Melon Slices instead of 9, so players making Melon Slices from them wouldn't be losing 5 slices per recipe
- Updated the ```root```, "Extra Dietary Options", and "The Gourmand" advancements (to account for the new food and recipe added)
- Added a ```root``` directory meant for storing recipe advancements (unachievable in normal gameplay)
- Moved the recipe advancements to ```morefoods:recipes/root``` (from ```minecraft:recipes/root```)
- Moved "The Gourmand" advancement to be under the ```root``` to make the advancement tree neater
- Renamed the following advancement filepaths:
  - ```extreme_dieting``` (from ```ate_monster_mash```)
  - ```caveman_breakfast``` (from ```ate_sniffer_egg```)
  - ```dragon_breakfast``` (from ```ate_dragon_egg```)

### Fixes
- Fixed a bug where Zombie Jerky didn't give the Hunger effect properly
- Fixed a bug where, apparently, I shipped this version WITHOUT a data folder! So the whole pack didn't exist! Whoopsies! :333

## [1.0.0-beta] - 2024-04-16

### Added
#### Foods
- Added a new "Stuffed Potato" food and recipe
#### Recipes & Data
- 2 new recipes were added to the Stonecutter (Undocumented)
#### Advancements
The following advancements have been added:
- "Jumbo Juice" for drinking Golden Apple Juice 
- "JUMBO Jumbo Juice" for drinking Enchanted Golden Apple Juice (Hidden Advancement) 
- "A Multipurpose Snack" for eating a Honeyball 
- "Accidental Alchemy" for crafting a Slime Block with Honeyballs

### Changed
- "Pumpkin Slice" recipe was moved to the Stonecutter (Undocumented)
- Melons no longer drop Melon Slices; Instead, they now drop as full blocks which must be cut in a Stonecutter for slices
- "The Gourmand" & "Extra Dietary Options" Advancements have been updated to include the new recipes added

### Removed
- "10,000 Calorie Meal" Advancement has been removed

### Fixes
- Several bug fixes (Undocumented)

## [1.0.0-alpha] - 2024-04-15

This is the first version of the project. No other information was written earlier, so I have nothing to write here...